pub struct PrologLanguage;Trait Implementations
Sourceimpl Clone for PrologLanguage
impl Clone for PrologLanguage
Sourcefn clone(&self) -> PrologLanguage
fn clone(&self) -> PrologLanguage
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PrologLanguage
impl Debug for PrologLanguage
Sourceimpl Default for PrologLanguage
impl Default for PrologLanguage
Sourcefn default() -> PrologLanguage
fn default() -> PrologLanguage
Returns the “default value” for a type. Read more
Sourceimpl Hash for PrologLanguage
impl Hash for PrologLanguage
Sourceimpl Language for PrologLanguage
impl Language for PrologLanguage
Sourcetype SyntaxKind = PrologSyntaxKind
type SyntaxKind = PrologSyntaxKind
The kind kind type used to represent different kind and node types in the language. Read more
Sourcetype TypedRoot = SourceFile
type TypedRoot = SourceFile
The root type for the parsed tree that represents the top-level structure of the language. Read more
Sourceimpl<'config> Lexer<PrologLanguage> for PrologLexer<'config>
impl<'config> Lexer<PrologLanguage> for PrologLexer<'config>
Sourcefn lex_incremental(
&self,
source: impl Source,
_changed: usize,
_cache: IncrementalCache<'_, PrologLanguage>,
) -> LexOutput<PrologLanguage>
fn lex_incremental( &self, source: impl Source, _changed: usize, _cache: IncrementalCache<'_, PrologLanguage>, ) -> LexOutput<PrologLanguage>
Tokenizes source text using an existing cache for incremental parsing. Read more
Sourcefn lex(
&self,
source: impl Source,
) -> OakDiagnostics<Vec<Token<<L as Language>::SyntaxKind>>>
fn lex( &self, source: impl Source, ) -> OakDiagnostics<Vec<Token<<L as Language>::SyntaxKind>>>
Tokenizes the given source text into a sequence of tokens. Read more
Sourceimpl Ord for PrologLanguage
impl Ord for PrologLanguage
Sourcefn cmp(&self, other: &PrologLanguage) -> Ordering
fn cmp(&self, other: &PrologLanguage) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for PrologLanguage
impl PartialEq for PrologLanguage
Sourceimpl PartialOrd for PrologLanguage
impl PartialOrd for PrologLanguage
impl Copy for PrologLanguage
impl Eq for PrologLanguage
impl StructuralPartialEq for PrologLanguage