PrologTokenType

Enum PrologTokenType 

pub enum PrologTokenType {
Show 57 variants Whitespace, Newline, Comment, Atom, Integer, Float, String, Variable, Unify, NotUnify, Equal, NotEqual, ArithEqual, ArithNotEqual, Less, Greater, LessEqual, GreaterEqual, Is, Plus, Minus, Multiply, Divide, IntDivide, Modulo, Power, BitwiseAnd, BitwiseOr, BitwiseXor, BitwiseNot, LeftShift, RightShift, LeftParen, RightParen, LeftBracket, RightBracket, LeftBrace, RightBrace, Comma, Dot, Pipe, Semicolon, Cut, Question, Colon, ColonMinus, QuestionMinus, Functor, Clause, Rule, Fact, Query, Directive, List, Structure, Root, Error,
}
Prolog token types.

Variants



Whitespace

Whitespace.



Newline

Newline.



Comment

Comment.



Atom

Atom.



Integer

Integer.



Float

Float.



String

String.



Variable

Variable.



Unify

Unification =.



NotUnify

Not unification \=.



Equal

Equal ==.



NotEqual

Not equal \==.



ArithEqual

Arithmetic equal =:=.



ArithNotEqual

Arithmetic not equal =\=.



Less

Less than <.



Greater

Greater than >.



LessEqual

Less or equal =<.



GreaterEqual

Greater or equal >=.



Is

Is is.



Plus

Plus +.



Minus

Minus -.



Multiply

Multiply *.



Divide

Divide /.



IntDivide

Integer divide //.



Modulo

Modulo mod.



Power

Power **.



BitwiseAnd

Bitwise and /\.



BitwiseOr

Bitwise or \/.



BitwiseXor

Bitwise xor xor.



BitwiseNot

Bitwise not \.



LeftShift

Left shift <<.



RightShift

Right shift >>.



LeftParen

Left parenthesis (.



RightParen

Right parenthesis ).



LeftBracket

Left bracket [.



RightBracket

Right bracket ].



LeftBrace

Left brace {.



RightBrace

Right brace }.



Comma

Comma ,.



Dot

Dot ..



Pipe

Pipe |.



Semicolon

Semicolon ;.



Cut

Cut !.



Question

Question mark ?.



Colon

Colon :.



ColonMinus

Colon minus :-.



QuestionMinus

Question minus ?-.



Functor

Functor.



Clause

Clause.



Rule

Rule.



Fact

Fact.



Query

Query.



Directive

Directive.



List

List.



Structure

Structure.



Root

Root.



Error

Error.

Implementations

Source

impl PrologTokenType

pub fn is_token(&self) -> bool

Check if this type is a token.

pub fn is_element(&self) -> bool

Check if this type is a structure element.